@@ -6,9 +6,10 @@ import sys
 root_dir = os.path.dirname(os.path.dirname(os.path.dirname(os.path.abspath(__file__))))
 sys.path.append(root_dir)
 
-from agentic_search.lib import get_llm
+from agentic_search.lib import get_websearch_llm
 from agentic_search.prompts.web import (
     get_claim_verification_web_search_query_prompt,
+    get_route_search_type_prompt,
     get_web_search_query_prompt,
     get_web_search_queries_prompt,
 )
@@ -20,7 +21,16 @@ def get_claim_verification_web_search_query_chain():
     """
     return (
         get_claim_verification_web_search_query_prompt()
-        | get_llm()
+        | get_websearch_llm()
+        | StrOutputParser()
+        | json.loads
+    )
+
+
+def get_route_search_type_chain():
+    return (
+        get_route_search_type_prompt()
+        | get_websearch_llm()
         | StrOutputParser()
         | json.loads
     )
@@ -32,7 +42,12 @@ def get_web_search_query_chain(excluded_queries: list[str] = []):
 
     Input key is `query`.
     """
-    return get_web_search_query_prompt(excluded_queries) | get_llm() | StrOutputParser() | json.loads
+    return (
+        get_web_search_query_prompt(excluded_queries)
+        | get_websearch_llm()
+        | StrOutputParser()
+        | json.loads
+    )
 
 
 def get_web_search_queries_chain(excluded_queries: list[str] = []):
@@ -41,4 +56,9 @@ def get_web_search_queries_chain(excluded_queries: list[str] = []):
 
     Input key is `query`.
     """
-    return get_web_search_queries_prompt(excluded_queries) | get_llm() | StrOutputParser() | json.loads
+    return (
+        get_web_search_queries_prompt(excluded_queries)
+        | get_websearch_llm()
+        | StrOutputParser()
+        | json.loads
+    )
